class QuestionsController < ApplicationController

  before_filter :find_category_id

  # GET /questions
  # GET /questions.json
  def index
    if defined?(@category_id)
      @questions = Question.find_all_by_category_id(@category_id)
    end

    respond_to do |format|
      format.html # index.html.erb
      format.json { render :json => @questions }
    end
  end

  # GET /questions/1
  # GET /questions/1.json
  def show
    @question = Question.find(params[:id])

    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @question }
    end
  end

  # GET /questions/new
  # GET /questions/new.json
  def new
    @question = Question.new
    (0..3).each do |i|
      choice = Choice.new
      choice.position = i
      @question.choices << choice
    end

    respond_to do |format|
      format.html # new.html.erb
      format.json { render :json => @question }
    end
  end

  # GET /questions/1/edit
  def edit
    @question = Question.find(params[:id])
  end

  # POST /questions
  # POST /questions.json
  def create
    @question = Question.new(params[:question])
    params[:choices].each_pair do |position, choice_params|
      choice = Choice.new(choice_params)
      choice.position = position.to_i
      @question.choices << choice
    end

    respond_to do |format|
      if @question.save
        format.html { redirect_to({:action => :show, :id => @question.id, :category_id => @category_id}, :notice => t(:notice_question_created)) }
        format.json { render :json => @question, :status => :created, :location => @question }
      else
        format.html { render :action => "new" }
        format.json { render :json => @question.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /questions/1
  # PUT /questions/1.json
  def update
    @question = Question.find(params[:id])
    params[:choices].each_pair do |position, choice_params|
      choice = Choice.find_by_position(position)
      choice_params[:is_correct] = 0 unless defined?(choice_params[:is_correct]) and choice_params[:is_correct] == "1"
      choice.update_attributes(choice_params)
    end

    respond_to do |format|
      if @question.update_attributes(params[:question])
        format.html { redirect_to({:action => :show, :id => @question.id, :category_id => @category_id}, :notice => t(:notice_question_updated)) }
        format.json { head :ok }
      else
        format.html { render :action => "edit" }
        format.json { render :json => @question.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /questions/1
  # DELETE /questions/1.json
  def destroy
    @question = Question.find(params[:id])
    @question.destroy

    respond_to do |format|
      format.html { redirect_to({:action => :index, :category_id => @category_id}) }
      format.json { head :ok }
    end
  end
  
private
  
  def find_category_id
    if defined?(params[:category_id])
      @category_id = params[:category_id].to_i
    else
      @category_id = nil
    end
  end

end
